#!/usr/bin/env python
"""Generate uppaal model from data of model learned with learnlib """
# Author: Harco Kuppens


import sys, re, pprint  # modules from standard lib (python 2.6 and later)

import pp_xml  # local module (which only uses standard lib modules)
import efsm    # local module ; next to standard lib modules it uses: pyuppaal module -> locally installed

import yaml



def learnlib2uppaal(json_filename_in,dot_filename_in,yaml_filename_in):

    #TODO: remove need of json file by config.yaml file
    configParams=yaml.load(file(yaml_filename_in))['configParams']
    min_value=configParams['min_value']
    max_value=configParams['max_value']
    lts_min_value=configParams['lts_min_value']
    lts_max_value=configParams['lts_max_value']
    lts_nat_type=configParams['lts_nat_type']
    lts_int_type=configParams['lts_int_type']

    [start_state,transitions]=efsm.get_lts_from_dotfile(dot_filename_in)

    # note: output has only unicode strings
    [inputs,outputs,cons,interfaces,min_value,max_value]=efsm.read_learner_data(json_filename_in)
    # min max value in json are used for learning


    number_params={}
    for i in interfaces:
       number_params[ i['method_name'] ] = len(i['param_types'])

    transitions=efsm.parse_labels_of_lts(transitions)
    transitions=efsm.apply_mapper_data_on_transitions(transitions,inputs,outputs,cons,number_params)
    transitions=efsm.split_input_and_output(transitions)


    model=efsm.get_uppaal_model(start_state,transitions,min_value,max_value,lts_min_value,lts_max_value,lts_nat_type,lts_int_type,interfaces,cons)

    #pp_xml.pprint(model.to_xml(),step="    ")
    return pp_xml.pformat(model.to_xml(),step="    ")


if __name__ == "__main__":
    print learnlib2uppaal(*sys.argv[1:])

